"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.trino.v1.access_control_pb2
import yandex.cloud.trino.v1.catalog_pb2
import yandex.cloud.trino.v1.cluster_pb2
import yandex.cloud.trino.v1.maintenance_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino Cluster resource to return."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list Trino clusters in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListClustersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListClustersResponse.next_page_token]
    returned by the previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can only use filtering with the [Cluster.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 1-63 characters long and match the regular expression `[a-zA-Z0-9_-]+`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClustersRequest.page_size], use the [next_page_token] as the value
    for the [ListClustersRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.trino.v1.cluster_pb2.Cluster]:
        """List of Trino Cluster resources."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.trino.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TRINO_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create Trino cluster in."""
    name: builtins.str
    """Name of the Trino cluster. The name must be unique within the folder."""
    description: builtins.str
    """Description of the Trino cluster."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster."""
    service_account_id: builtins.str
    """Service account used to access Cloud resources."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Trino cluster as `` key:value `` pairs.
        For example: {"env": "prod"}.
        """

    @property
    def trino(self) -> global___TrinoConfigSpec:
        """Configuration of Trino components."""

    @property
    def network(self) -> yandex.cloud.trino.v1.cluster_pb2.NetworkConfig:
        """Network related configuration options."""

    @property
    def logging(self) -> yandex.cloud.trino.v1.cluster_pb2.LoggingConfig:
        """Cloud logging configuration."""

    @property
    def maintenance_window(self) -> yandex.cloud.trino.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        trino: global___TrinoConfigSpec | None = ...,
        network: yandex.cloud.trino.v1.cluster_pb2.NetworkConfig | None = ...,
        deletion_protection: builtins.bool = ...,
        service_account_id: builtins.str = ...,
        logging: yandex.cloud.trino.v1.cluster_pb2.LoggingConfig | None = ...,
        maintenance_window: yandex.cloud.trino.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["logging", b"logging", "maintenance_window", b"maintenance_window", "network", b"network", "trino", b"trino"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "name", b"name", "network", b"network", "service_account_id", b"service_account_id", "trino", b"trino"]) -> None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class TrinoConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOGS_FIELD_NUMBER: builtins.int
    COORDINATOR_CONFIG_FIELD_NUMBER: builtins.int
    WORKER_CONFIG_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ACCESS_CONTROL_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Trino version.
    Format: "Number".
    """
    @property
    def catalogs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.trino.v1.catalog_pb2.CatalogSpec]:
        """List of catalogs that enable integration with various data sources.
        Each catalog defines a connection to an external data source that Trino can query.
        """

    @property
    def coordinator_config(self) -> yandex.cloud.trino.v1.cluster_pb2.CoordinatorConfig:
        """Configuration for the coordinator, specifying computational resources and other settings."""

    @property
    def worker_config(self) -> yandex.cloud.trino.v1.cluster_pb2.WorkerConfig:
        """Configuration for worker nodes, including scaling policy and computational resources."""

    @property
    def retry_policy(self) -> yandex.cloud.trino.v1.cluster_pb2.RetryPolicyConfig:
        """Configuration for retry policy, specifying the spooling storage destination and other settings."""

    @property
    def access_control(self) -> yandex.cloud.trino.v1.access_control_pb2.AccessControlConfig:
        """Configuration for access control, specifying the fine-grained access rules."""

    def __init__(
        self,
        *,
        catalogs: collections.abc.Iterable[yandex.cloud.trino.v1.catalog_pb2.CatalogSpec] | None = ...,
        coordinator_config: yandex.cloud.trino.v1.cluster_pb2.CoordinatorConfig | None = ...,
        worker_config: yandex.cloud.trino.v1.cluster_pb2.WorkerConfig | None = ...,
        retry_policy: yandex.cloud.trino.v1.cluster_pb2.RetryPolicyConfig | None = ...,
        version: builtins.str = ...,
        access_control: yandex.cloud.trino.v1.access_control_pb2.AccessControlConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_control", b"access_control", "coordinator_config", b"coordinator_config", "retry_policy", b"retry_policy", "worker_config", b"worker_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_control", b"access_control", "catalogs", b"catalogs", "coordinator_config", b"coordinator_config", "retry_policy", b"retry_policy", "version", b"version", "worker_config", b"worker_config"]) -> None: ...

global___TrinoConfigSpec = TrinoConfigSpec

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class UpdateCoordinatorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> yandex.cloud.trino.v1.cluster_pb2.Resources:
        """Configuration for computational resources assigned to the coordinator instance."""

    def __init__(
        self,
        *,
        resources: yandex.cloud.trino.v1.cluster_pb2.Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___UpdateCoordinatorConfig = UpdateCoordinatorConfig

@typing.final
class UpdateWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class WorkerScalePolicy(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        FIXED_SCALE_FIELD_NUMBER: builtins.int
        AUTO_SCALE_FIELD_NUMBER: builtins.int
        @property
        def fixed_scale(self) -> yandex.cloud.trino.v1.cluster_pb2.FixedScalePolicy:
            """A fixed scaling policy that specifies a fixed number of worker instances."""

        @property
        def auto_scale(self) -> yandex.cloud.trino.v1.cluster_pb2.AutoScalePolicy:
            """A scaling policy that dynamically adjusts the number of worker instances
            based on the cluster's workload. The system automatically increases or
            decreases the number of instances within the defined range.
            """

        def __init__(
            self,
            *,
            fixed_scale: yandex.cloud.trino.v1.cluster_pb2.FixedScalePolicy | None = ...,
            auto_scale: yandex.cloud.trino.v1.cluster_pb2.AutoScalePolicy | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["auto_scale", b"auto_scale", "fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["auto_scale", b"auto_scale", "fixed_scale", b"fixed_scale", "scale_type", b"scale_type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["scale_type", b"scale_type"]) -> typing.Literal["fixed_scale", "auto_scale"] | None: ...

    RESOURCES_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> yandex.cloud.trino.v1.cluster_pb2.Resources:
        """Configuration for computational resources for worker instances."""

    @property
    def scale_policy(self) -> global___UpdateWorkerConfig.WorkerScalePolicy:
        """Configuration for scaling policy for worker instances."""

    def __init__(
        self,
        *,
        resources: yandex.cloud.trino.v1.cluster_pb2.Resources | None = ...,
        scale_policy: global___UpdateWorkerConfig.WorkerScalePolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources", "scale_policy", b"scale_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources", "scale_policy", b"scale_policy"]) -> None: ...

global___UpdateWorkerConfig = UpdateWorkerConfig

@typing.final
class UpdateTrinoConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COORDINATOR_CONFIG_FIELD_NUMBER: builtins.int
    WORKER_CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    ACCESS_CONTROL_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Trino version.
    Format: "Number".
    """
    @property
    def coordinator_config(self) -> global___UpdateCoordinatorConfig:
        """Configuration for the coordinator, specifying computational resources and other settings."""

    @property
    def worker_config(self) -> global___UpdateWorkerConfig:
        """Configuration for worker nodes, including scaling policy and computational resources."""

    @property
    def retry_policy(self) -> yandex.cloud.trino.v1.cluster_pb2.RetryPolicyConfig:
        """Configuration for retry policy, specifying the spooling storage destination and other settings."""

    @property
    def access_control(self) -> yandex.cloud.trino.v1.access_control_pb2.AccessControlConfig:
        """Configuration for access control, specifying the fine-grained access rules."""

    def __init__(
        self,
        *,
        coordinator_config: global___UpdateCoordinatorConfig | None = ...,
        worker_config: global___UpdateWorkerConfig | None = ...,
        version: builtins.str = ...,
        retry_policy: yandex.cloud.trino.v1.cluster_pb2.RetryPolicyConfig | None = ...,
        access_control: yandex.cloud.trino.v1.access_control_pb2.AccessControlConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_control", b"access_control", "coordinator_config", b"coordinator_config", "retry_policy", b"retry_policy", "worker_config", b"worker_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_control", b"access_control", "coordinator_config", b"coordinator_config", "retry_policy", b"retry_policy", "version", b"version", "worker_config", b"worker_config"]) -> None: ...

global___UpdateTrinoConfigSpec = UpdateTrinoConfigSpec

@typing.final
class UpdateNetworkConfigSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User security groups."""

    def __init__(
        self,
        *,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["security_group_ids", b"security_group_ids"]) -> None: ...

global___UpdateNetworkConfigSpec = UpdateNetworkConfigSpec

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    TRINO_FIELD_NUMBER: builtins.int
    NETWORK_SPEC_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster."""
    name: builtins.str
    """Name of the Trino cluster. The name must be unique within the folder."""
    description: builtins.str
    """Description of the Trino cluster."""
    deletion_protection: builtins.bool
    """Deletion Protection inhibits deletion of the cluster."""
    service_account_id: builtins.str
    """Service account used to access Cloud resources."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the Trino cluster as `` key:value `` pairs.
        For example: {"env": "prod"}.
        """

    @property
    def trino(self) -> global___UpdateTrinoConfigSpec:
        """Configuration of Trino components."""

    @property
    def network_spec(self) -> global___UpdateNetworkConfigSpec:
        """Network related configuration options."""

    @property
    def logging(self) -> yandex.cloud.trino.v1.cluster_pb2.LoggingConfig:
        """Cloud logging configuration."""

    @property
    def maintenance_window(self) -> yandex.cloud.trino.v1.maintenance_pb2.MaintenanceWindow:
        """Window of maintenance operations."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        deletion_protection: builtins.bool = ...,
        trino: global___UpdateTrinoConfigSpec | None = ...,
        network_spec: global___UpdateNetworkConfigSpec | None = ...,
        service_account_id: builtins.str = ...,
        logging: yandex.cloud.trino.v1.cluster_pb2.LoggingConfig | None = ...,
        maintenance_window: yandex.cloud.trino.v1.maintenance_pb2.MaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["logging", b"logging", "maintenance_window", b"maintenance_window", "network_spec", b"network_spec", "trino", b"trino", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "deletion_protection", b"deletion_protection", "description", b"description", "labels", b"labels", "logging", b"logging", "maintenance_window", b"maintenance_window", "name", b"name", "network_spec", b"network_spec", "service_account_id", b"service_account_id", "trino", b"trino", "update_mask", b"update_mask"]) -> None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the deleting Trino cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster that is being started."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster that is being stopped."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino cluster."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata

@typing.final
class ListClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Trino Cluster resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListClusterOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.  To get the next page of results, set [page_token] to the [ListClusterOperationsResponse.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterOperationsRequest = ListClusterOperationsRequest

@typing.final
class ListClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClusterOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListClusterOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of Operation resources for the specified Trino cluster."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListClusterOperationsResponse = ListClusterOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/desktop.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/desktop.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/clouddesktop/v1/desktop.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xbd\x05\n\x07\x44\x65sktop\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65sktop_group_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x06status\x18\x05 \x01(\x0e\x32\x30.yandex.cloud.clouddesktop.v1.api.Desktop.Status\x12\x0c\n\x04name\x18\x0b \x01(\t\x12>\n\tresources\x18\x15 \x01(\x0b\x32+.yandex.cloud.clouddesktop.v1.api.Resources\x12N\n\x12network_interfaces\x18\x16 \x03(\x0b\x32\x32.yandex.cloud.clouddesktop.v1.api.NetworkInterface\x12\x35\n\x05users\x18\x17 \x03(\x0b\x32&.yandex.cloud.clouddesktop.v1.api.User\x12\x45\n\x06labels\x18\x18 \x03(\x0b\x32\x35.yandex.cloud.clouddesktop.v1.api.Desktop.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaf\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\x0e\n\nRESTARTING\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x12\x0c\n\x08STARTING\x10\x06\x12\x0c\n\x08STOPPING\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x12\t\n\x05\x45RROR\x10\t\x12\x13\n\x0f\x43REATION_FAILED\x10\nJ\x04\x08\x0c\x10\x15J\x04\x08\x06\x10\x0b\"^\n\tResources\x12\x17\n\x06memory\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x16\n\x05\x63ores\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12 \n\rcore_fraction\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\"N\n\x04User\x12!\n\nsubject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12#\n\x0csubject_type\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\"U\n\x10NetworkInterface\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\tsubnet_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50Bq\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.desktop_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_DESKTOP_LABELSENTRY']._loaded_options = None
  _globals['_DESKTOP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCES'].fields_by_name['memory']._loaded_options = None
  _globals['_RESOURCES'].fields_by_name['memory']._serialized_options = b'\372\3071\003>=1'
  _globals['_RESOURCES'].fields_by_name['cores']._loaded_options = None
  _globals['_RESOURCES'].fields_by_name['cores']._serialized_options = b'\372\3071\003>=1'
  _globals['_RESOURCES'].fields_by_name['core_fraction']._loaded_options = None
  _globals['_RESOURCES'].fields_by_name['core_fraction']._serialized_options = b'\372\3071\0050-100'
  _globals['_USER'].fields_by_name['subject_id']._loaded_options = None
  _globals['_USER'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_USER'].fields_by_name['subject_type']._loaded_options = None
  _globals['_USER'].fields_by_name['subject_type']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_NETWORKINTERFACE'].fields_by_name['network_id']._loaded_options = None
  _globals['_NETWORKINTERFACE'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_NETWORKINTERFACE'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_NETWORKINTERFACE'].fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DESKTOP']._serialized_start=145
  _globals['_DESKTOP']._serialized_end=846
  _globals['_DESKTOP_LABELSENTRY']._serialized_start=611
  _globals['_DESKTOP_LABELSENTRY']._serialized_end=656
  _globals['_DESKTOP_STATUS']._serialized_start=659
  _globals['_DESKTOP_STATUS']._serialized_end=834
  _globals['_RESOURCES']._serialized_start=848
  _globals['_RESOURCES']._serialized_end=942
  _globals['_USER']._serialized_start=944
  _globals['_USER']._serialized_end=1022
  _globals['_NETWORKINTERFACE']._serialized_start=1024
  _globals['_NETWORKINTERFACE']._serialized_end=1109
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANYTIME_FIELD_NUMBER: builtins.int
    WEEKLY_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    @property
    def anytime(self) -> global___AnytimeMaintenanceWindow: ...
    @property
    def weekly_maintenance_window(self) -> global___WeeklyMaintenanceWindow: ...
    def __init__(
        self,
        *,
        anytime: global___AnytimeMaintenanceWindow | None = ...,
        weekly_maintenance_window: global___WeeklyMaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["anytime", b"anytime", "policy", b"policy", "weekly_maintenance_window", b"weekly_maintenance_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["anytime", b"anytime", "policy", b"policy", "weekly_maintenance_window", b"weekly_maintenance_window"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["policy", b"policy"]) -> typing.Literal["anytime", "weekly_maintenance_window"] | None: ...

global___MaintenanceWindow = MaintenanceWindow

@typing.final
class AnytimeMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AnytimeMaintenanceWindow = AnytimeMaintenanceWindow

@typing.final
class WeeklyMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _WeekDay:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WeekDayEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WeeklyMaintenanceWindow._WeekDay.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        WEEK_DAY_UNSPECIFIED: WeeklyMaintenanceWindow._WeekDay.ValueType  # 0
        MON: WeeklyMaintenanceWindow._WeekDay.ValueType  # 1
        TUE: WeeklyMaintenanceWindow._WeekDay.ValueType  # 2
        WED: WeeklyMaintenanceWindow._WeekDay.ValueType  # 3
        THU: WeeklyMaintenanceWindow._WeekDay.ValueType  # 4
        FRI: WeeklyMaintenanceWindow._WeekDay.ValueType  # 5
        SAT: WeeklyMaintenanceWindow._WeekDay.ValueType  # 6
        SUN: WeeklyMaintenanceWindow._WeekDay.ValueType  # 7

    class WeekDay(_WeekDay, metaclass=_WeekDayEnumTypeWrapper): ...
    WEEK_DAY_UNSPECIFIED: WeeklyMaintenanceWindow.WeekDay.ValueType  # 0
    MON: WeeklyMaintenanceWindow.WeekDay.ValueType  # 1
    TUE: WeeklyMaintenanceWindow.WeekDay.ValueType  # 2
    WED: WeeklyMaintenanceWindow.WeekDay.ValueType  # 3
    THU: WeeklyMaintenanceWindow.WeekDay.ValueType  # 4
    FRI: WeeklyMaintenanceWindow.WeekDay.ValueType  # 5
    SAT: WeeklyMaintenanceWindow.WeekDay.ValueType  # 6
    SUN: WeeklyMaintenanceWindow.WeekDay.ValueType  # 7

    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    day: global___WeeklyMaintenanceWindow.WeekDay.ValueType
    hour: builtins.int
    """Hour of the day in UTC."""
    def __init__(
        self,
        *,
        day: global___WeeklyMaintenanceWindow.WeekDay.ValueType = ...,
        hour: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["day", b"day", "hour", b"hour"]) -> None: ...

global___WeeklyMaintenanceWindow = WeeklyMaintenanceWindow

@typing.final
class MaintenanceOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DELAYED_UNTIL_FIELD_NUMBER: builtins.int
    LATEST_MAINTENANCE_TIME_FIELD_NUMBER: builtins.int
    NEXT_MAINTENANCE_WINDOW_TIME_FIELD_NUMBER: builtins.int
    info: builtins.str
    @property
    def delayed_until(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def latest_maintenance_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def next_maintenance_window_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        info: builtins.str = ...,
        delayed_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        latest_maintenance_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        next_maintenance_window_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delayed_until", b"delayed_until", "latest_maintenance_time", b"latest_maintenance_time", "next_maintenance_window_time", b"next_maintenance_window_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["delayed_until", b"delayed_until", "info", b"info", "latest_maintenance_time", b"latest_maintenance_time", "next_maintenance_window_time", b"next_maintenance_window_time"]) -> None: ...

global___MaintenanceOperation = MaintenanceOperation



from typing import TYPE_CHECKING, Optional

from yandex.cloud.iam.v1.service_account_service_pb2 import ListServiceAccountsRequest
from yandex.cloud.iam.v1.service_account_service_pb2_grpc import (
    ServiceAccountServiceStub,
)
from yandex.cloud.vpc.v1.network_service_pb2 import ListNetworksRequest
from yandex.cloud.vpc.v1.network_service_pb2_grpc import NetworkServiceStub
from yandex.cloud.vpc.v1.subnet_service_pb2 import ListSubnetsRequest
from yandex.cloud.vpc.v1.subnet_service_pb2_grpc import SubnetServiceStub

if TYPE_CHECKING:
    from yandexcloud._sdk import SDK


class Helpers:
    def __init__(self, sdk: "SDK"):
        self.sdk = sdk

    def find_service_account_id(self, folder_id: str) -> str:
        """
        Get service account id in case the folder has the only one service account

        :param folder_id: ID of the folder
        :return ID of the service account
        """
        service = self.sdk.client(ServiceAccountServiceStub)
        service_accounts = service.List(ListServiceAccountsRequest(folder_id=folder_id)).service_accounts
        if len(service_accounts) == 1:
            return service_accounts[0].id
        if len(service_accounts) == 0:
            raise RuntimeError(f"There are no service accounts in folder {folder_id}, please create it.")
        raise RuntimeError(f"There are more than one service account in folder {folder_id}, please specify it")

    def find_network_id(self, folder_id: str) -> str:
        """
        Get ID of the first network in folder

        :param folder_id: ID of the folder
        :return ID of the network
        """
        networks = self.sdk.client(NetworkServiceStub).List(ListNetworksRequest(folder_id=folder_id)).networks
        if not networks:
            raise RuntimeError(f"No networks in folder: {folder_id}")
        if len(networks) > 1:
            raise RuntimeError("There are more than one network in folder {folder_id}, please specify it")
        return networks[0].id

    def find_subnet_id(self, folder_id: str, zone_id: str, network_id: Optional[str] = None) -> str:
        """
        Get ID of the subnetwork of specified network in specified availability zone

        :param folder_id: ID of the folder
        :param zone_id: ID of the availability zone
        :param network_id: ID of the network
        :return ID of the subnetwork
        """
        subnet_service = self.sdk.client(SubnetServiceStub)
        subnets = subnet_service.List(ListSubnetsRequest(folder_id=folder_id)).subnets
        if network_id:
            applicable = [s for s in subnets if s.zone_id == zone_id and s.network_id == network_id]
        else:
            applicable = [s for s in subnets if s.zone_id == zone_id]
        if len(applicable) == 1:
            return applicable[0].id
        if len(applicable) == 0:
            raise RuntimeError(f"There are no subnets in {zone_id} zone, please create it.")
        raise RuntimeError(f"There are more than one subnet in {zone_id} zone, please specify it")



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.backup.v1.policy_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Archive(google.protobuf.message.Message):
    """Archive is a container that holds backups of Compute Cloud instance."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _EncryptionAlgorithm:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EncryptionAlgorithmEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Archive._EncryptionAlgorithm.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ENCRYPTION_ALGORITHM_UNSPECIFIED: Archive._EncryptionAlgorithm.ValueType  # 0
        NONE: Archive._EncryptionAlgorithm.ValueType  # 1
        AES128: Archive._EncryptionAlgorithm.ValueType  # 2
        AES192: Archive._EncryptionAlgorithm.ValueType  # 3
        AES256: Archive._EncryptionAlgorithm.ValueType  # 4

    class EncryptionAlgorithm(_EncryptionAlgorithm, metaclass=_EncryptionAlgorithmEnumTypeWrapper):
        """Encryption Algorithm for underlying backups: 
        `ENCRYPTION_ALGORITHM_UNSPECIFIED`, `NONE`, `AES128`, `AES192`, 
        `AES256`.
        """

    ENCRYPTION_ALGORITHM_UNSPECIFIED: Archive.EncryptionAlgorithm.ValueType  # 0
    NONE: Archive.EncryptionAlgorithm.ValueType  # 1
    AES128: Archive.EncryptionAlgorithm.ValueType  # 2
    AES192: Archive.EncryptionAlgorithm.ValueType  # 3
    AES256: Archive.EncryptionAlgorithm.ValueType  # 4

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Archive._Action.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTION_UNSPECIFIED: Archive._Action.ValueType  # 0
        REFRESH: Archive._Action.ValueType  # 1
        DELETE_BY_AGENT: Archive._Action.ValueType  # 2

    class Action(_Action, metaclass=_ActionEnumTypeWrapper):
        """Action with archive backup: `ACTION_UNSPECIFIED`, `REFRESH`,
        `DELETE_BY_AGENT`.
        """

    ACTION_UNSPECIFIED: Archive.Action.ValueType  # 0
    REFRESH: Archive.Action.ValueType  # 1
    DELETE_BY_AGENT: Archive.Action.ValueType  # 2

    @typing.final
    class ArchiveAttributes(google.protobuf.message.Message):
        """Archive attributes."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AAIB_FIELD_NUMBER: builtins.int
        URI_FIELD_NUMBER: builtins.int
        aaib: builtins.str
        """Archive attribute. Default value: `0`."""
        uri: builtins.str
        """URI of the backup archive."""
        def __init__(
            self,
            *,
            aaib: builtins.str = ...,
            uri: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["aaib", b"aaib", "uri", b"uri"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VAULT_ID_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    COMPRESSED_DATA_SIZE_FIELD_NUMBER: builtins.int
    DATA_SIZE_FIELD_NUMBER: builtins.int
    ORIGINAL_DATA_SIZE_FIELD_NUMBER: builtins.int
    LOGICAL_SIZE_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LAST_BACKUP_CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_SEEN_AT_FIELD_NUMBER: builtins.int
    PROTECTED_BY_PASSWORD_FIELD_NUMBER: builtins.int
    ENCRYPTION_ALGORITHM_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    BACKUP_PLAN_ID_FIELD_NUMBER: builtins.int
    BACKUP_PLAN_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    CONSISTENT_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the backup."""
    name: builtins.str
    """Name of the backup."""
    vault_id: builtins.str
    """ID of the backup vault."""
    size: builtins.int
    """Archive size."""
    compressed_data_size: builtins.int
    """Compressed data size."""
    data_size: builtins.int
    """Data size."""
    original_data_size: builtins.int
    """Original data size."""
    logical_size: builtins.int
    """Logical size."""
    format: yandex.cloud.backup.v1.policy_pb2.Format.ValueType
    protected_by_password: builtins.bool
    """If this field is true, it means that any of encryption algorithm
    has been chosen.
    """
    encryption_algorithm: global___Archive.EncryptionAlgorithm.ValueType
    backup_plan_id: builtins.str
    """Backup plan ID."""
    backup_plan_name: builtins.str
    """Backup plan name."""
    description: builtins.str
    """Backup plan description."""
    display_name: builtins.str
    """Display name, e.g. `INSTANCE_NAME - POLICY_NAME`."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    consistent: builtins.bool
    """If this field is true, it means that the archive is consistent."""
    deleted: builtins.bool
    """If this field is true, it means that the archive was deleted."""
    resource_id: builtins.str
    """Resource ID."""
    @property
    def attributes(self) -> global___Archive.ArchiveAttributes:
        """Archive attributes."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_backup_created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_seen_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def actions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Archive.Action.ValueType]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        vault_id: builtins.str = ...,
        attributes: global___Archive.ArchiveAttributes | None = ...,
        size: builtins.int = ...,
        compressed_data_size: builtins.int = ...,
        data_size: builtins.int = ...,
        original_data_size: builtins.int = ...,
        logical_size: builtins.int = ...,
        format: yandex.cloud.backup.v1.policy_pb2.Format.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_backup_created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_seen_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        protected_by_password: builtins.bool = ...,
        encryption_algorithm: global___Archive.EncryptionAlgorithm.ValueType = ...,
        actions: collections.abc.Iterable[global___Archive.Action.ValueType] | None = ...,
        backup_plan_id: builtins.str = ...,
        backup_plan_name: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        consistent: builtins.bool = ...,
        deleted: builtins.bool = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attributes", b"attributes", "created_at", b"created_at", "last_backup_created_at", b"last_backup_created_at", "last_seen_at", b"last_seen_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["actions", b"actions", "attributes", b"attributes", "backup_plan_id", b"backup_plan_id", "backup_plan_name", b"backup_plan_name", "compressed_data_size", b"compressed_data_size", "compute_instance_id", b"compute_instance_id", "consistent", b"consistent", "created_at", b"created_at", "data_size", b"data_size", "deleted", b"deleted", "description", b"description", "display_name", b"display_name", "encryption_algorithm", b"encryption_algorithm", "format", b"format", "id", b"id", "last_backup_created_at", b"last_backup_created_at", "last_seen_at", b"last_seen_at", "logical_size", b"logical_size", "name", b"name", "original_data_size", b"original_data_size", "protected_by_password", b"protected_by_password", "resource_id", b"resource_id", "size", b"size", "updated_at", b"updated_at", "vault_id", b"vault_id"]) -> None: ...

global___Archive = Archive

@typing.final
class Volume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FREE_SPACE_FIELD_NUMBER: builtins.int
    IS_BOOTABLE_FIELD_NUMBER: builtins.int
    IS_SYSTEM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    MOUNT_STRID_FIELD_NUMBER: builtins.int
    free_space: builtins.int
    """Free space in the volume."""
    is_bootable: builtins.bool
    """If this field is true, it means that the volume is bootable."""
    is_system: builtins.bool
    """If this field is true, it means that the volume is a system volume."""
    name: builtins.str
    """Volume name."""
    size: builtins.int
    """Volume size."""
    mount_strid: builtins.str
    """Mount string ID."""
    def __init__(
        self,
        *,
        free_space: builtins.int = ...,
        is_bootable: builtins.bool = ...,
        is_system: builtins.bool = ...,
        name: builtins.str = ...,
        size: builtins.int = ...,
        mount_strid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["free_space", b"free_space", "is_bootable", b"is_bootable", "is_system", b"is_system", "mount_strid", b"mount_strid", "name", b"name", "size", b"size"]) -> None: ...

global___Volume = Volume

@typing.final
class Disk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_MODEL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    device_model: builtins.str
    """Device model."""
    name: builtins.str
    """Disk name."""
    size: builtins.int
    """Disk size."""
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Volume]: ...
    def __init__(
        self,
        *,
        device_model: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.int = ...,
        volumes: collections.abc.Iterable[global___Volume] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_model", b"device_model", "name", b"name", "size", b"size", "volumes", b"volumes"]) -> None: ...

global___Disk = Disk

@typing.final
class Backup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Backup._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Backup._Type.ValueType  # 0
        FULL: Backup._Type.ValueType  # 1
        INCREMENTAL: Backup._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """Backup type.
        For detailed information, please see [Backup types](/docs/backup/concepts/backup#types).
        """

    TYPE_UNSPECIFIED: Backup.Type.ValueType  # 0
    FULL: Backup.Type.ValueType  # 1
    INCREMENTAL: Backup.Type.ValueType  # 2

    @typing.final
    class BackupAttributes(google.protobuf.message.Message):
        """Backup attributes."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STREAM_NAME_FIELD_NUMBER: builtins.int
        URI_FIELD_NUMBER: builtins.int
        stream_name: builtins.str
        """Backup stream name."""
        uri: builtins.str
        """URI of the backup archive."""
        def __init__(
            self,
            *,
            stream_name: builtins.str = ...,
            uri: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["stream_name", b"stream_name", "uri", b"uri"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    VAULT_ID_FIELD_NUMBER: builtins.int
    ARCHIVE_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_SEEN_AT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    DEDUPLICATED_SIZE_FIELD_NUMBER: builtins.int
    BACKED_UP_DATA_SIZE_FIELD_NUMBER: builtins.int
    ORIGINAL_DATA_SIZE_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    DISKS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DELETED_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the backup."""
    vault_id: builtins.str
    """ID of the backup vault."""
    archive_id: builtins.str
    """ID of the backup archive."""
    size: builtins.int
    """Backup size."""
    deduplicated_size: builtins.int
    """Deduplicated backup size."""
    backed_up_data_size: builtins.int
    """Backed up data size."""
    original_data_size: builtins.int
    """Original data size."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    type: global___Backup.Type.ValueType
    deleted: builtins.bool
    """If this field is true, it means that the backup was deleted."""
    policy_id: builtins.str
    """[Policy](/docs/backup/concepts/policy) ID."""
    resource_id: builtins.str
    """Resource ID. It identifies Compute Cloud instance in backup service."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_seen_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def attributes(self) -> global___Backup.BackupAttributes: ...
    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Disk]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        vault_id: builtins.str = ...,
        archive_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_seen_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        size: builtins.int = ...,
        deduplicated_size: builtins.int = ...,
        backed_up_data_size: builtins.int = ...,
        original_data_size: builtins.int = ...,
        attributes: global___Backup.BackupAttributes | None = ...,
        compute_instance_id: builtins.str = ...,
        disks: collections.abc.Iterable[global___Disk] | None = ...,
        type: global___Backup.Type.ValueType = ...,
        deleted: builtins.bool = ...,
        policy_id: builtins.str = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["attributes", b"attributes", "created_at", b"created_at", "last_seen_at", b"last_seen_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archive_id", b"archive_id", "attributes", b"attributes", "backed_up_data_size", b"backed_up_data_size", "compute_instance_id", b"compute_instance_id", "created_at", b"created_at", "deduplicated_size", b"deduplicated_size", "deleted", b"deleted", "disks", b"disks", "id", b"id", "last_seen_at", b"last_seen_at", "original_data_size", b"original_data_size", "policy_id", b"policy_id", "resource_id", b"resource_id", "size", b"size", "type", b"type", "vault_id", b"vault_id"]) -> None: ...

global___Backup = Backup

@typing.final
class BackupFile(google.protobuf.message.Message):
    """BackupFile represents a single unit of file or directory system inside the backup."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BackupFile._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: BackupFile._Type.ValueType  # 0
        TYPE_DIR: BackupFile._Type.ValueType  # 1
        TYPE_FILE: BackupFile._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """Type of the file."""

    TYPE_UNSPECIFIED: BackupFile.Type.ValueType  # 0
    TYPE_DIR: BackupFile.Type.ValueType  # 1
    TYPE_FILE: BackupFile.Type.ValueType  # 2

    @typing.final
    class Actions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RESTORE_TO_DISK_FIELD_NUMBER: builtins.int
        GO_TO_LOCATION_FIELD_NUMBER: builtins.int
        restore_to_disk: builtins.bool
        """Allows to send request to restore item to disk"""
        go_to_location: builtins.bool
        """Allows to move to location by id."""
        def __init__(
            self,
            *,
            restore_to_disk: builtins.bool = ...,
            go_to_location: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["go_to_location", b"go_to_location", "restore_to_disk", b"restore_to_disk"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    PARENT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    FULL_PATH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ACTIONS_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the item. Should be used as source ID in case of listing."""
    type: global___BackupFile.Type.ValueType
    """Type of the item."""
    full_path: builtins.str
    """Absolute path of the item."""
    name: builtins.str
    """Name of the directory / file."""
    size: builtins.int
    """Size in bytes of the item."""
    @property
    def parent_id(self) -> google.protobuf.wrappers_pb2.StringValue:
        """Might be empty if this is root directory."""

    @property
    def actions(self) -> global___BackupFile.Actions:
        """Actions that might be done on the object."""

    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        parent_id: google.protobuf.wrappers_pb2.StringValue | None = ...,
        type: global___BackupFile.Type.ValueType = ...,
        full_path: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.int = ...,
        actions: global___BackupFile.Actions | None = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["actions", b"actions", "modified_at", b"modified_at", "parent_id", b"parent_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["actions", b"actions", "full_path", b"full_path", "id", b"id", "modified_at", b"modified_at", "name", b"name", "parent_id", b"parent_id", "size", b"size", "type", b"type"]) -> None: ...

global___BackupFile = BackupFile



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HBARule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ConnectionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ConnectionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HBARule._ConnectionType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONNECTION_TYPE_UNSPECIFIED: HBARule._ConnectionType.ValueType  # 0
        HOST: HBARule._ConnectionType.ValueType  # 1
        """Matches connection attempts made using TCP/IP."""
        HOSTSSL: HBARule._ConnectionType.ValueType  # 2
        """Matches connection attempts made using TCP/IP, but only when the connection is made with SSL encryption."""
        HOSTNOSSL: HBARule._ConnectionType.ValueType  # 3
        """Matches connection attempts made over TCP/IP that do not use SSL."""

    class ConnectionType(_ConnectionType, metaclass=_ConnectionTypeEnumTypeWrapper): ...
    CONNECTION_TYPE_UNSPECIFIED: HBARule.ConnectionType.ValueType  # 0
    HOST: HBARule.ConnectionType.ValueType  # 1
    """Matches connection attempts made using TCP/IP."""
    HOSTSSL: HBARule.ConnectionType.ValueType  # 2
    """Matches connection attempts made using TCP/IP, but only when the connection is made with SSL encryption."""
    HOSTNOSSL: HBARule.ConnectionType.ValueType  # 3
    """Matches connection attempts made over TCP/IP that do not use SSL."""

    class _AuthMethod:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AuthMethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HBARule._AuthMethod.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        AUTH_METHOD_UNSPECIFIED: HBARule._AuthMethod.ValueType  # 0
        MD5: HBARule._AuthMethod.ValueType  # 1
        """Perform SCRAM-SHA-256 or MD5 authentication to verify the user's password."""
        LDAP: HBARule._AuthMethod.ValueType  # 2
        """Perform LDAP authentication, if MDB_GREENPLUM_LDAP flag is set"""
        REJECT: HBARule._AuthMethod.ValueType  # 3
        """Disable authentication"""
        IAM: HBARule._AuthMethod.ValueType  # 4
        """Perform authentication with IAM token"""

    class AuthMethod(_AuthMethod, metaclass=_AuthMethodEnumTypeWrapper): ...
    AUTH_METHOD_UNSPECIFIED: HBARule.AuthMethod.ValueType  # 0
    MD5: HBARule.AuthMethod.ValueType  # 1
    """Perform SCRAM-SHA-256 or MD5 authentication to verify the user's password."""
    LDAP: HBARule.AuthMethod.ValueType  # 2
    """Perform LDAP authentication, if MDB_GREENPLUM_LDAP flag is set"""
    REJECT: HBARule.AuthMethod.ValueType  # 3
    """Disable authentication"""
    IAM: HBARule.AuthMethod.ValueType  # 4
    """Perform authentication with IAM token"""

    PRIORITY_FIELD_NUMBER: builtins.int
    CONNECTION_TYPE_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    AUTH_METHOD_FIELD_NUMBER: builtins.int
    priority: builtins.int
    """Priority of the Greenplum cluster rule."""
    connection_type: global___HBARule.ConnectionType.ValueType
    database: builtins.str
    """Specifies which database names this record matches."""
    user: builtins.str
    """Specifies which database role names this user matches."""
    address: builtins.str
    """Specifies the client machine addresses that this record matches."""
    auth_method: global___HBARule.AuthMethod.ValueType
    """Specifies the authentication method to use when a connection matches this record.
    https://gpdb.docs.pivotal.io/6-6/security-guide/topics/Authenticate.html
    """
    def __init__(
        self,
        *,
        priority: builtins.int = ...,
        connection_type: global___HBARule.ConnectionType.ValueType = ...,
        database: builtins.str = ...,
        user: builtins.str = ...,
        address: builtins.str = ...,
        auth_method: global___HBARule.AuthMethod.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address", "auth_method", b"auth_method", "connection_type", b"connection_type", "database", b"database", "priority", b"priority", "user", b"user"]) -> None: ...

global___HBARule = HBARule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/spark/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/spark/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.spark.v1 import maintenance_pb2 as yandex_dot_cloud_dot_spark_dot_v1_dot_maintenance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/spark/v1/cluster.proto\x12\x15yandex.cloud.spark.v1\x1a\'yandex/cloud/spark/v1/maintenance.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf8\x06\n\x07\x43luster\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12:\n\x06labels\x18\x06 \x03(\x0b\x32*.yandex.cloud.spark.v1.Cluster.LabelsEntry\x12\x34\n\x06\x63onfig\x18\x07 \x01(\x0b\x32$.yandex.cloud.spark.v1.ClusterConfig\x12\x35\n\x06status\x18\x08 \x01(\x0e\x32%.yandex.cloud.spark.v1.Cluster.Status\x12\x35\n\x07network\x18\t \x01(\x0b\x32$.yandex.cloud.spark.v1.NetworkConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x12$\n\x12service_account_id\x18\x0b \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x35\n\x07logging\x18\x0c \x01(\x0b\x32$.yandex.cloud.spark.v1.LoggingConfig\x12-\n\x06health\x18\r \x01(\x0e\x32\x1d.yandex.cloud.spark.v1.Health\x12,\n\x05links\x18\x0e \x03(\x0b\x32\x1d.yandex.cloud.spark.v1.UILink\x12\x44\n\x12maintenance_window\x18\x0f \x01(\x0b\x32(.yandex.cloud.spark.v1.MaintenanceWindow\x12\x46\n\x11planned_operation\x18\x10 \x01(\x0b\x32+.yandex.cloud.spark.v1.MaintenanceOperation\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"\x87\x02\n\rClusterConfig\x12\x42\n\x0eresource_pools\x18\x01 \x01(\x0b\x32$.yandex.cloud.spark.v1.ResourcePoolsB\x04\xe8\xc7\x31\x01\x12\x42\n\x0ehistory_server\x18\x02 \x01(\x0b\x32*.yandex.cloud.spark.v1.HistoryServerConfig\x12\x39\n\x0c\x64\x65pendencies\x18\x03 \x01(\x0b\x32#.yandex.cloud.spark.v1.Dependencies\x12\x33\n\tmetastore\x18\x04 \x01(\x0b\x32 .yandex.cloud.spark.v1.Metastore\"\x8b\x02\n\x17UpdateClusterConfigSpec\x12<\n\x0eresource_pools\x18\x01 \x01(\x0b\x32$.yandex.cloud.spark.v1.ResourcePools\x12\x42\n\x0ehistory_server\x18\x02 \x01(\x0b\x32*.yandex.cloud.spark.v1.HistoryServerConfig\x12\x39\n\x0c\x64\x65pendencies\x18\x03 \x01(\x0b\x32#.yandex.cloud.spark.v1.Dependencies\x12\x33\n\tmetastore\x18\x04 \x01(\x0b\x32 .yandex.cloud.spark.v1.Metastore\"&\n\x13HistoryServerConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"?\n\rNetworkConfig\x12\x12\n\nsubnet_ids\x18\x01 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x02 \x03(\t\"5\n\x17UpdateNetworkConfigSpec\x12\x1a\n\x12security_group_ids\x18\x01 \x03(\t\"\x87\x01\n\rResourcePools\x12\x39\n\x06\x64river\x18\x01 \x01(\x0b\x32#.yandex.cloud.spark.v1.ResourcePoolB\x04\xe8\xc7\x31\x01\x12;\n\x08\x65xecutor\x18\x02 \x01(\x0b\x32#.yandex.cloud.spark.v1.ResourcePoolB\x04\xe8\xc7\x31\x01\"x\n\x0cResourcePool\x12(\n\x12resource_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x0cscale_policy\x18\x02 \x01(\x0b\x32\".yandex.cloud.spark.v1.ScalePolicyB\x04\xe8\xc7\x31\x01\"\x99\x02\n\x0bScalePolicy\x12\x44\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32-.yandex.cloud.spark.v1.ScalePolicy.FixedScaleH\x00\x12\x42\n\nauto_scale\x18\x02 \x01(\x0b\x32,.yandex.cloud.spark.v1.ScalePolicy.AutoScaleH\x00\x1a%\n\nFixedScale\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100\x1a\x45\n\tAutoScale\x12\x1b\n\x08min_size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1b\n\x08max_size\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100B\x12\n\nscale_type\x12\x04\xc0\xc1\x31\x01\":\n\x0c\x44\x65pendencies\x12\x14\n\x0cpip_packages\x18\x01 \x03(\t\x12\x14\n\x0c\x64\x65\x62_packages\x18\x02 \x03(\t\")\n\tMetastore\x12\x1c\n\ncluster_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xa6\x01\n\rLoggingConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x38\n\tfolder_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12;\n\x0clog_group_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x42\r\n\x0b\x64\x65stination\"#\n\x06UILink\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t*?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x42\\\n\x19yandex.cloud.api.spark.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/spark/v1;sparkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.spark.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.spark.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/spark/v1;spark'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER'].fields_by_name['id']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLUSTER'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CLUSTERCONFIG'].fields_by_name['resource_pools']._loaded_options = None
  _globals['_CLUSTERCONFIG'].fields_by_name['resource_pools']._serialized_options = b'\350\3071\001'
  _globals['_RESOURCEPOOLS'].fields_by_name['driver']._loaded_options = None
  _globals['_RESOURCEPOOLS'].fields_by_name['driver']._serialized_options = b'\350\3071\001'
  _globals['_RESOURCEPOOLS'].fields_by_name['executor']._loaded_options = None
  _globals['_RESOURCEPOOLS'].fields_by_name['executor']._serialized_options = b'\350\3071\001'
  _globals['_RESOURCEPOOL'].fields_by_name['resource_preset_id']._loaded_options = None
  _globals['_RESOURCEPOOL'].fields_by_name['resource_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESOURCEPOOL'].fields_by_name['scale_policy']._loaded_options = None
  _globals['_RESOURCEPOOL'].fields_by_name['scale_policy']._serialized_options = b'\350\3071\001'
  _globals['_SCALEPOLICY_FIXEDSCALE'].fields_by_name['size']._loaded_options = None
  _globals['_SCALEPOLICY_FIXEDSCALE'].fields_by_name['size']._serialized_options = b'\372\3071\0051-100'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['min_size']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['min_size']._serialized_options = b'\372\3071\0050-100'
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['max_size']._loaded_options = None
  _globals['_SCALEPOLICY_AUTOSCALE'].fields_by_name['max_size']._serialized_options = b'\372\3071\0051-100'
  _globals['_SCALEPOLICY'].oneofs_by_name['scale_type']._loaded_options = None
  _globals['_SCALEPOLICY'].oneofs_by_name['scale_type']._serialized_options = b'\300\3011\001'
  _globals['_METASTORE'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_METASTORE'].fields_by_name['cluster_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LOGGINGCONFIG'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LOGGINGCONFIG'].fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_LOGGINGCONFIG'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_LOGGINGCONFIG'].fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_HEALTH']._serialized_start=2607
  _globals['_HEALTH']._serialized_end=2670
  _globals['_CLUSTER']._serialized_start=168
  _globals['_CLUSTER']._serialized_end=1056
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=888
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=933
  _globals['_CLUSTER_STATUS']._serialized_start=935
  _globals['_CLUSTER_STATUS']._serialized_end=1056
  _globals['_CLUSTERCONFIG']._serialized_start=1059
  _globals['_CLUSTERCONFIG']._serialized_end=1322
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_start=1325
  _globals['_UPDATECLUSTERCONFIGSPEC']._serialized_end=1592
  _globals['_HISTORYSERVERCONFIG']._serialized_start=1594
  _globals['_HISTORYSERVERCONFIG']._serialized_end=1632
  _globals['_NETWORKCONFIG']._serialized_start=1634
  _globals['_NETWORKCONFIG']._serialized_end=1697
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_start=1699
  _globals['_UPDATENETWORKCONFIGSPEC']._serialized_end=1752
  _globals['_RESOURCEPOOLS']._serialized_start=1755
  _globals['_RESOURCEPOOLS']._serialized_end=1890
  _globals['_RESOURCEPOOL']._serialized_start=1892
  _globals['_RESOURCEPOOL']._serialized_end=2012
  _globals['_SCALEPOLICY']._serialized_start=2015
  _globals['_SCALEPOLICY']._serialized_end=2296
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_start=2168
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_end=2205
  _globals['_SCALEPOLICY_AUTOSCALE']._serialized_start=2207
  _globals['_SCALEPOLICY_AUTOSCALE']._serialized_end=2276
  _globals['_DEPENDENCIES']._serialized_start=2298
  _globals['_DEPENDENCIES']._serialized_end=2356
  _globals['_METASTORE']._serialized_start=2358
  _globals['_METASTORE']._serialized_end=2399
  _globals['_LOGGINGCONFIG']._serialized_start=2402
  _globals['_LOGGINGCONFIG']._serialized_end=2568
  _globals['_UILINK']._serialized_start=2570
  _globals['_UILINK']._serialized_end=2605
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.mdb.postgresql.v1.user_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the PostgreSQL User resource to return.
    To get the name of the user, use a [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___GetUserRequest = GetUserRequest

@typing.final
class ListUsersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list PostgreSQL users in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListUsersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the [ListUsersResponse.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListUsersRequest = ListUsersRequest

@typing.final
class ListUsersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListUsersRequest.page_size], use the `next_page_token` as the value
    for the [ListUsersRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.postgresql.v1.user_pb2.User]:
        """List of PostgreSQL User resources."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[yandex.cloud.mdb.postgresql.v1.user_pb2.User] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "users", b"users"]) -> None: ...

global___ListUsersResponse = ListUsersResponse

@typing.final
class CreateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster to create a user in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    @property
    def user_spec(self) -> yandex.cloud.mdb.postgresql.v1.user_pb2.UserSpec:
        """Properties of the user to be created."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_spec: yandex.cloud.mdb.postgresql.v1.user_pb2.UserSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user_spec", b"user_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_spec", b"user_spec"]) -> None: ...

global___CreateUserRequest = CreateUserRequest

@typing.final
class CreateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user is being created in."""
    user_name: builtins.str
    """Name of the user that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___CreateUserMetadata = CreateUserMetadata

@typing.final
class UpdateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    CONN_LIMIT_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LOGIN_FIELD_NUMBER: builtins.int
    GRANTS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    USER_PASSWORD_ENCRYPTION_FIELD_NUMBER: builtins.int
    GENERATE_PASSWORD_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to.
    To get the cluster ID use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to be updated.
    To get the name of the user use a [UserService.List] request.
    """
    password: builtins.str
    """New password for the user."""
    conn_limit: builtins.int
    """Maximum number of database connections available to the user.

    When used in session pooling, this setting limits the number of connections to every single host in PostgreSQL cluster. In this case, the setting's value must be greater than the total number of connections that backend services can open to access the PostgreSQL cluster. The setting's value should not exceed the value of the [Cluster.config.postgresql_config.max_connections] setting.

    When used in transaction pooling, this setting limits the number of user's active transactions; therefore, in this mode user can open thousands of connections, but only `N` concurrent connections will be opened, where `N` is the value of the setting.

    Minimum value: `10` (default: `50`), when used in session pooling.
    """
    user_password_encryption: yandex.cloud.mdb.postgresql.v1.user_pb2.UserPasswordEncryption.ValueType
    """New password-based authentication method for user.
    Possible values are `` USER_PASSWORD_ENCRYPTION_MD5 `` or `` USER_PASSWORD_ENCRYPTION_SCRAM_SHA_256 ``.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the PostgreSQL User resource should be updated."""

    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.postgresql.v1.user_pb2.Permission]:
        """Set of permissions granted to the user to access specific databases."""

    @property
    def settings(self) -> yandex.cloud.mdb.postgresql.v1.user_pb2.UserSettings: ...
    @property
    def login(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """This flag defines whether the user can login to a PostgreSQL database.

        Default value: `true` (login is allowed).
        """

    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A set of roles and privileges that are granted to the user.

        For more information, see [the documentation](/docs/managed-postgresql/operations/grant).
        """

    @property
    def deletion_protection(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Deletion Protection inhibits deletion of the user

        Default value: `unspecified` (inherits cluster's deletion_protection)
        """

    @property
    def generate_password(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Generate password using Connection Manager."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[yandex.cloud.mdb.postgresql.v1.user_pb2.Permission] | None = ...,
        conn_limit: builtins.int = ...,
        settings: yandex.cloud.mdb.postgresql.v1.user_pb2.UserSettings | None = ...,
        login: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        grants: collections.abc.Iterable[builtins.str] | None = ...,
        deletion_protection: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        user_password_encryption: yandex.cloud.mdb.postgresql.v1.user_pb2.UserPasswordEncryption.ValueType = ...,
        generate_password: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "generate_password", b"generate_password", "login", b"login", "settings", b"settings", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "conn_limit", b"conn_limit", "deletion_protection", b"deletion_protection", "generate_password", b"generate_password", "grants", b"grants", "login", b"login", "password", b"password", "permissions", b"permissions", "settings", b"settings", "update_mask", b"update_mask", "user_name", b"user_name", "user_password_encryption", b"user_password_encryption"]) -> None: ...

global___UpdateUserRequest = UpdateUserRequest

@typing.final
class UpdateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___UpdateUserMetadata = UpdateUserMetadata

@typing.final
class DeleteUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to delete.
    To get the name of the user, use a [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserRequest = DeleteUserRequest

@typing.final
class DeleteUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserMetadata = DeleteUserMetadata

@typing.final
class GrantUserPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to grant the permission to.
    To get the name of the user, use a [UserService.List] request.
    """
    @property
    def permission(self) -> yandex.cloud.mdb.postgresql.v1.user_pb2.Permission:
        """Permission that should be granted to the specified user."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        permission: yandex.cloud.mdb.postgresql.v1.user_pb2.Permission | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["permission", b"permission"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "permission", b"permission", "user_name", b"user_name"]) -> None: ...

global___GrantUserPermissionRequest = GrantUserPermissionRequest

@typing.final
class GrantUserPermissionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user that is being granted a permission."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___GrantUserPermissionMetadata = GrantUserPermissionMetadata

@typing.final
class RevokeUserPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to revoke a permission from.
    To get the name of the user, use a [UserService.List] request.
    """
    database_name: builtins.str
    """Name of the database that the user should lose access to."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name", "user_name", b"user_name"]) -> None: ...

global___RevokeUserPermissionRequest = RevokeUserPermissionRequest

@typing.final
class RevokeUserPermissionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the PostgreSQL cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user whose permission is being revoked."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___RevokeUserPermissionMetadata = RevokeUserPermissionMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.kms.v1.symmetric_crypto_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SymmetricCryptoServiceStub:
    """--- Data plane for KMS symmetric cryptography operations

    Set of methods that perform symmetric encryption and decryption.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Encrypt: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricEncryptRequest,
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricEncryptResponse,
    ]
    """Encrypts given plaintext with the specified key."""

    Decrypt: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricDecryptRequest,
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricDecryptResponse,
    ]
    """Decrypts the given ciphertext with the specified key."""

    ReEncrypt: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricReEncryptRequest,
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricReEncryptResponse,
    ]
    """Re-encrypts a ciphertext with the specified KMS key."""

    GenerateDataKey: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.GenerateDataKeyRequest,
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.GenerateDataKeyResponse,
    ]
    """Generates a new symmetric data encryption key (not a KMS key) and returns
    the generated key as plaintext and as ciphertext encrypted with the specified symmetric KMS key.
    """

class SymmetricCryptoServiceAsyncStub:
    """--- Data plane for KMS symmetric cryptography operations

    Set of methods that perform symmetric encryption and decryption.
    """

    Encrypt: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricEncryptRequest,
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricEncryptResponse,
    ]
    """Encrypts given plaintext with the specified key."""

    Decrypt: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricDecryptRequest,
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricDecryptResponse,
    ]
    """Decrypts the given ciphertext with the specified key."""

    ReEncrypt: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricReEncryptRequest,
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricReEncryptResponse,
    ]
    """Re-encrypts a ciphertext with the specified KMS key."""

    GenerateDataKey: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.GenerateDataKeyRequest,
        yandex.cloud.kms.v1.symmetric_crypto_service_pb2.GenerateDataKeyResponse,
    ]
    """Generates a new symmetric data encryption key (not a KMS key) and returns
    the generated key as plaintext and as ciphertext encrypted with the specified symmetric KMS key.
    """

class SymmetricCryptoServiceServicer(metaclass=abc.ABCMeta):
    """--- Data plane for KMS symmetric cryptography operations

    Set of methods that perform symmetric encryption and decryption.
    """

    @abc.abstractmethod
    def Encrypt(
        self,
        request: yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricEncryptRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricEncryptResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricEncryptResponse]]:
        """Encrypts given plaintext with the specified key."""

    @abc.abstractmethod
    def Decrypt(
        self,
        request: yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricDecryptRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricDecryptResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricDecryptResponse]]:
        """Decrypts the given ciphertext with the specified key."""

    @abc.abstractmethod
    def ReEncrypt(
        self,
        request: yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricReEncryptRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricReEncryptResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.symmetric_crypto_service_pb2.SymmetricReEncryptResponse]]:
        """Re-encrypts a ciphertext with the specified KMS key."""

    @abc.abstractmethod
    def GenerateDataKey(
        self,
        request: yandex.cloud.kms.v1.symmetric_crypto_service_pb2.GenerateDataKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.kms.v1.symmetric_crypto_service_pb2.GenerateDataKeyResponse, collections.abc.Awaitable[yandex.cloud.kms.v1.symmetric_crypto_service_pb2.GenerateDataKeyResponse]]:
        """Generates a new symmetric data encryption key (not a KMS key) and returns
        the generated key as plaintext and as ciphertext encrypted with the specified symmetric KMS key.
        """

def add_SymmetricCryptoServiceServicer_to_server(servicer: SymmetricCryptoServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/spark/v1/job_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/spark/v1/job_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.spark.v1 import job_pb2 as yandex_dot_cloud_dot_spark_dot_v1_dot_job__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/spark/v1/job_service.proto\x12\x15yandex.cloud.spark.v1\x1a\x1fyandex/cloud/spark/v1/job.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\"O\n\rGetJobRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x06job_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8d\x01\n\x0fListJobsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"`\n\x10ListJobsResponse\x12(\n\x04jobs\x18\x01 \x03(\x0b\x32\x1a.yandex.cloud.spark.v1.Job\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200\"\xd8\x02\n\x10\x43reateJobRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x34\n\tspark_job\x18\x03 \x01(\x0b\x32\x1f.yandex.cloud.spark.v1.SparkJobH\x00\x12\x38\n\x0bpyspark_job\x18\x04 \x01(\x0b\x32!.yandex.cloud.spark.v1.PysparkJobH\x00\x12\x43\n\x11spark_connect_job\x18\x05 \x01(\x0b\x32&.yandex.cloud.spark.v1.SparkConnectJobH\x00\x12$\n\x12service_account_id\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50B\n\n\x08job_specJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\"O\n\x11\x43reateJobMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x06job_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"R\n\x10\x43\x61ncelJobRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x06job_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x94\x01\n\x11ListJobLogRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x06job_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\tpage_size\x18\x03 \x01(\x03\x42\r\xfa\xc7\x31\t<=1048576\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=200\"I\n\x12ListJobLogResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=2002\xfc\x03\n\nJobService\x12Y\n\x04List\x12&.yandex.cloud.spark.v1.ListJobsRequest\x1a\'.yandex.cloud.spark.v1.ListJobsResponse\"\x00\x12r\n\x06\x43reate\x12\'.yandex.cloud.spark.v1.CreateJobRequest\x1a!.yandex.cloud.operation.Operation\"\x1c\xb2\xd2*\x18\n\x11\x43reateJobMetadata\x12\x03Job\x12I\n\x03Get\x12$.yandex.cloud.spark.v1.GetJobRequest\x1a\x1a.yandex.cloud.spark.v1.Job\"\x00\x12`\n\x07ListLog\x12(.yandex.cloud.spark.v1.ListJobLogRequest\x1a).yandex.cloud.spark.v1.ListJobLogResponse\"\x00\x12r\n\x06\x43\x61ncel\x12\'.yandex.cloud.spark.v1.CancelJobRequest\x1a!.yandex.cloud.operation.Operation\"\x1c\xb2\xd2*\x18\n\x11\x43reateJobMetadata\x12\x03JobB\\\n\x19yandex.cloud.api.spark.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/spark/v1;sparkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.spark.v1.job_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.spark.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/spark/v1;spark'
  _globals['_GETJOBREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETJOBREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETJOBREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_GETJOBREQUEST'].fields_by_name['job_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=200'
  _globals['_LISTJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTJOBSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTJOBSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=200'
  _globals['_CREATEJOBREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEJOBREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEJOBREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEJOBREQUEST'].fields_by_name['service_account_id']._loaded_options = None
  _globals['_CREATEJOBREQUEST'].fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATEJOBMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEJOBMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEJOBMETADATA'].fields_by_name['job_id']._loaded_options = None
  _globals['_CREATEJOBMETADATA'].fields_by_name['job_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CANCELJOBREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CANCELJOBREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CANCELJOBREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_CANCELJOBREQUEST'].fields_by_name['job_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['job_id']._loaded_options = None
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['job_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\t<=1048576'
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTJOBLOGREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=200'
  _globals['_LISTJOBLOGRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTJOBLOGRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=200'
  _globals['_JOBSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_JOBSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\030\n\021CreateJobMetadata\022\003Job'
  _globals['_JOBSERVICE'].methods_by_name['Cancel']._loaded_options = None
  _globals['_JOBSERVICE'].methods_by_name['Cancel']._serialized_options = b'\262\322*\030\n\021CreateJobMetadata\022\003Job'
  _globals['_GETJOBREQUEST']._serialized_start=204
  _globals['_GETJOBREQUEST']._serialized_end=283
  _globals['_LISTJOBSREQUEST']._serialized_start=286
  _globals['_LISTJOBSREQUEST']._serialized_end=427
  _globals['_LISTJOBSRESPONSE']._serialized_start=429
  _globals['_LISTJOBSRESPONSE']._serialized_end=525
  _globals['_CREATEJOBREQUEST']._serialized_start=528
  _globals['_CREATEJOBREQUEST']._serialized_end=872
  _globals['_CREATEJOBMETADATA']._serialized_start=874
  _globals['_CREATEJOBMETADATA']._serialized_end=953
  _globals['_CANCELJOBREQUEST']._serialized_start=955
  _globals['_CANCELJOBREQUEST']._serialized_end=1037
  _globals['_LISTJOBLOGREQUEST']._serialized_start=1040
  _globals['_LISTJOBLOGREQUEST']._serialized_end=1188
  _globals['_LISTJOBLOGRESPONSE']._serialized_start=1190
  _globals['_LISTJOBLOGRESPONSE']._serialized_end=1263
  _globals['_JOBSERVICE']._serialized_start=1266
  _globals['_JOBSERVICE']._serialized_end=1774
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.baremetal.v1alpha.disk_pb2
import yandex.cloud.baremetal.v1alpha.storage_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Server(google.protobuf.message.Message):
    """A Server resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Server._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Server._Status.ValueType  # 0
        """Unspecified server status."""
        PROVISIONING: Server._Status.ValueType  # 1
        """Server is waiting for to be allocated from the hardware pool."""
        STOPPING: Server._Status.ValueType  # 3
        """Server is being stopped."""
        STOPPED: Server._Status.ValueType  # 4
        """Server has been stopped."""
        STARTING: Server._Status.ValueType  # 5
        """Server is being started."""
        RESTARTING: Server._Status.ValueType  # 6
        """Server is being restarted."""
        ERROR: Server._Status.ValueType  # 7
        """Server encountered a problem and cannot operate."""
        DELETING: Server._Status.ValueType  # 8
        """Server is being deleted."""
        REINSTALLING: Server._Status.ValueType  # 9
        """Server operating system is being reinstalled."""
        UPDATING: Server._Status.ValueType  # 10
        """Server is being updated."""
        QUARANTINED: Server._Status.ValueType  # 12
        """Server has been quarantined"""
        RUNNING: Server._Status.ValueType  # 14
        """Server is running normaly"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Server status."""

    STATUS_UNSPECIFIED: Server.Status.ValueType  # 0
    """Unspecified server status."""
    PROVISIONING: Server.Status.ValueType  # 1
    """Server is waiting for to be allocated from the hardware pool."""
    STOPPING: Server.Status.ValueType  # 3
    """Server is being stopped."""
    STOPPED: Server.Status.ValueType  # 4
    """Server has been stopped."""
    STARTING: Server.Status.ValueType  # 5
    """Server is being started."""
    RESTARTING: Server.Status.ValueType  # 6
    """Server is being restarted."""
    ERROR: Server.Status.ValueType  # 7
    """Server encountered a problem and cannot operate."""
    DELETING: Server.Status.ValueType  # 8
    """Server is being deleted."""
    REINSTALLING: Server.Status.ValueType  # 9
    """Server operating system is being reinstalled."""
    UPDATING: Server.Status.ValueType  # 10
    """Server is being updated."""
    QUARANTINED: Server.Status.ValueType  # 12
    """Server has been quarantined"""
    RUNNING: Server.Status.ValueType  # 14
    """Server is running normaly"""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    HARDWARE_POOL_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    OS_SETTINGS_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    CONFIGURATION_ID_FIELD_NUMBER: builtins.int
    DISKS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the server."""
    cloud_id: builtins.str
    """ID of the cloud that the server belongs to."""
    folder_id: builtins.str
    """ID of the folder that the server belongs to."""
    name: builtins.str
    """Name of the server.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the server."""
    zone_id: builtins.str
    """ID of the availability zone where the server is resides."""
    hardware_pool_id: builtins.str
    """ID of the hardware pool that the server belongs to."""
    status: global___Server.Status.ValueType
    """Status of the server."""
    configuration_id: builtins.str
    """ID of the configuration that was used to create the server."""
    @property
    def os_settings(self) -> global___OsSettings:
        """Operating system specific settings of the server. Optional, will be empty if the server is
        provisioned without an operating system.
        """

    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkInterface]:
        """Array of network interfaces that are attached to the instance."""

    @property
    def disks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.disk_pb2.Disk]:
        """Array of disks that are attached to the server."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        zone_id: builtins.str = ...,
        hardware_pool_id: builtins.str = ...,
        status: global___Server.Status.ValueType = ...,
        os_settings: global___OsSettings | None = ...,
        network_interfaces: collections.abc.Iterable[global___NetworkInterface] | None = ...,
        configuration_id: builtins.str = ...,
        disks: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.disk_pb2.Disk] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "os_settings", b"os_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "configuration_id", b"configuration_id", "created_at", b"created_at", "description", b"description", "disks", b"disks", "folder_id", b"folder_id", "hardware_pool_id", b"hardware_pool_id", "id", b"id", "labels", b"labels", "name", b"name", "network_interfaces", b"network_interfaces", "os_settings", b"os_settings", "status", b"status", "zone_id", b"zone_id"]) -> None: ...

global___Server = Server

@typing.final
class NetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    MAC_ADDRESS_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_SUBNET_FIELD_NUMBER: builtins.int
    PUBLIC_SUBNET_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the network interface."""
    mac_address: builtins.str
    """MAC address that is assigned to the network interface."""
    ip_address: builtins.str
    """IPv4 address that is assigned to the server for this network interface."""
    @property
    def private_subnet(self) -> global___PrivateSubnetNetworkInterface:
        """Private subnet."""

    @property
    def public_subnet(self) -> global___PublicSubnetNetworkInterface:
        """Public subnet."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        mac_address: builtins.str = ...,
        ip_address: builtins.str = ...,
        private_subnet: global___PrivateSubnetNetworkInterface | None = ...,
        public_subnet: global___PublicSubnetNetworkInterface | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["private_subnet", b"private_subnet", "public_subnet", b"public_subnet", "subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "ip_address", b"ip_address", "mac_address", b"mac_address", "private_subnet", b"private_subnet", "public_subnet", b"public_subnet", "subnet", b"subnet"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["subnet", b"subnet"]) -> typing.Literal["private_subnet", "public_subnet"] | None: ...

global___NetworkInterface = NetworkInterface

@typing.final
class PrivateSubnetNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_SUBNET_ID_FIELD_NUMBER: builtins.int
    private_subnet_id: builtins.str
    """ID of the private subnet."""
    def __init__(
        self,
        *,
        private_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_subnet_id", b"private_subnet_id"]) -> None: ...

global___PrivateSubnetNetworkInterface = PrivateSubnetNetworkInterface

@typing.final
class PublicSubnetNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_SUBNET_ID_FIELD_NUMBER: builtins.int
    public_subnet_id: builtins.str
    """ID of the public subnet.

    A new ephemeral public subnet will be created if not specified.
    """
    def __init__(
        self,
        *,
        public_subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["public_subnet_id", b"public_subnet_id"]) -> None: ...

global___PublicSubnetNetworkInterface = PublicSubnetNetworkInterface

@typing.final
class OsSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_ID_FIELD_NUMBER: builtins.int
    SSH_PUBLIC_KEY_FIELD_NUMBER: builtins.int
    STORAGES_FIELD_NUMBER: builtins.int
    image_id: builtins.str
    """ID of the image that the server was created from."""
    ssh_public_key: builtins.str
    """Public SSH key of the server."""
    @property
    def storages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.storage_pb2.Storage]:
        """List of storages."""

    def __init__(
        self,
        *,
        image_id: builtins.str = ...,
        ssh_public_key: builtins.str = ...,
        storages: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.storage_pb2.Storage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["image_id", b"image_id", "ssh_public_key", b"ssh_public_key", "storages", b"storages"]) -> None: ...

global___OsSettings = OsSettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class HBARuleServiceStub:
    """A set of methods for managing Greenplum clusters."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesRequest,
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesResponse,
    ]
    """Retrieves a list of HBA rules for Greenplum clusters."""

    ListAtRevision: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesAtRevisionRequest,
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesResponse,
    ]
    """Retrieves a list of HBA rules for Greenplum clusters for particular revision."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.CreateHBARuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create single HBA rule for the specified Greenplum cluster to the end of HBA rules list."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.UpdateHBARuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update specified HBA rule for the specified Greenplum cluster without changind it order."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.DeleteHBARuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specified HBA rule for the specified Greenplum cluster."""

    BatchUpdate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.BatchUpdateHBARulesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Modifies all HBA rules for the specified Greenplum cluster."""

class HBARuleServiceAsyncStub:
    """A set of methods for managing Greenplum clusters."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesRequest,
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesResponse,
    ]
    """Retrieves a list of HBA rules for Greenplum clusters."""

    ListAtRevision: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesAtRevisionRequest,
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesResponse,
    ]
    """Retrieves a list of HBA rules for Greenplum clusters for particular revision."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.CreateHBARuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create single HBA rule for the specified Greenplum cluster to the end of HBA rules list."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.UpdateHBARuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update specified HBA rule for the specified Greenplum cluster without changind it order."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.DeleteHBARuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specified HBA rule for the specified Greenplum cluster."""

    BatchUpdate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.BatchUpdateHBARulesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Modifies all HBA rules for the specified Greenplum cluster."""

class HBARuleServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Greenplum clusters."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesResponse, collections.abc.Awaitable[yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesResponse]]:
        """Retrieves a list of HBA rules for Greenplum clusters."""

    @abc.abstractmethod
    def ListAtRevision(
        self,
        request: yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesAtRevisionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesResponse, collections.abc.Awaitable[yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.ListHBARulesResponse]]:
        """Retrieves a list of HBA rules for Greenplum clusters for particular revision."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.CreateHBARuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create single HBA rule for the specified Greenplum cluster to the end of HBA rules list."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.UpdateHBARuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update specified HBA rule for the specified Greenplum cluster without changind it order."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.DeleteHBARuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete specified HBA rule for the specified Greenplum cluster."""

    @abc.abstractmethod
    def BatchUpdate(
        self,
        request: yandex.cloud.mdb.greenplum.v1.hba_rule_service_pb2.BatchUpdateHBARulesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Modifies all HBA rules for the specified Greenplum cluster."""

def add_HBARuleServiceServicer_to_server(servicer: HBARuleServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
